#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client-restricted
version:              0.1.0
visibility:           public
id:                   http-client-restricted-0.1.0-3nMssA4SAUMCazYiwFwslT
key:                  http-client-restricted-0.1.0-3nMssA4SAUMCazYiwFwslT
license:              MIT
copyright:            2018 Joey Hess, 2013 Michael Snoyman
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess
synopsis:             restricting the servers that http-client will use
description:
    Addition to the http-client and http-client-tls
    libraries, that restricts the HTTP servers that can be used.

    This is useful when a security policy needs to eg, prevent connections to
    HTTP servers on localhost or a local network, or only allow connections
    to a specific HTTP server.

    It handles restricting redirects as well as the initial HTTP connection,
    and it also guards against DNS poisoning attacks.

category:             Network
abi:                  62d9f0c654eec26ebfb3fc8be61acf50
exposed:              True
exposed-modules:      Network.HTTP.Client.Restricted
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-client-restricted-0.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-client-restricted-0.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-client-restricted-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-client-restricted
hs-libraries:         HShttp-client-restricted-0.1.0-3nMssA4SAUMCazYiwFwslT
depends:
    base-4.18.2.1 crypton-connection-0.4.5-9LgRycmLJ5JCEtpoXDN2t7
    data-default-0.7.1.3-5y5VYR5qIF5L6R23Ybd297
    http-client-0.7.19-2UeAfN562pLBCSD1YRqnzt
    http-client-tls-0.3.6.4-56nnBZPBE3OE9myuO98KLr
    network-3.1.4.0-9YNBV8UGnKyEcMIeWoZU
    network-bsd-2.8.1.0-HSRnHKsRtRc73HaWRgg9z3
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv

haddock-interfaces:
    /usr/share/doc/haskell-http-client-restricted/html/http-client-restricted.haddock

haddock-html:         /usr/share/doc/haskell-http-client-restricted/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

